/*
Author: Aaron Nech
This processing class defines a screen entity with position and dimension.
This class is abstract and must be extended to be functional.
*/

abstract public class Entity {
  private float x, y;
  private float w, h;
  
  //post: constructs a new Entity object at a given location.
  public Entity(float wi, float he) {
    this(0, 0, wi, he);
  }
  
  //post: constructs a new Entity object at a given location.
  public Entity(float xPos, float yPos, float wi, float he) {
    x = xPos;
    y = yPos;
    w = wi;
    h = he;
  }
  
  //pre: other is not null
  //post: returns true if two entities are currently colliding, false otherwise
  public boolean collide(Entity other) {
    return !(x > other.x + other.w ||
            x + w < other.x ||
            y > other.y + other.h ||
            y + h < other.y);
  }
  
  //post: returns the x value of this entity
  public float getX() {
    return x;
  }
  
  //post: returns the y value of this entity
  public float getY() {
    return y;
  }
  
  //post: sets the x value of this entity to the given x value
  public void setX(float xPos) {
     x = xPos;
  }
  
  //post: sets the y value of this entity to the given y value
  public void setY(float yPos) {
     y = yPos;
  }
  
  //post: returns the width value of this entity
  public float getWidth() {
    return w;
  }
  
  //post: returns the height value of this entity
  public float getHeight() {
    return h;
  }
  
  //post: sets the width value of this entity to the given width value
  public void setWidth(float wi) {
     w = wi;
  }
  
  //post: sets the height value of this entity to the given height value
  public void setHeight(float he) {
     h = he;
  }
  
  //forces subclasses to have a render and update implementation
  abstract public void render();
  abstract public void update();
}
